@@ -321,14 +321,49 @@ corpus = [
             "5.8. bis 16.8.",
             "5. bis zum 16.8.",
             "vom 05.08.2018 zum 16.08.2018",
+            "from 2018/08/05 to 2018/08/16",
         ],
     ),
+    (
+        "Interval[]{2018-08-05 X:X (X/X) - 2018-08-16 X:X (X/X)}",
+        "2018-03-07T12:43",
+        [
+            "vom 05.08.2018 zum 16.08.2018",
+            "vom 05.08 zum 16.08",
+            "vom 05.08. zum 16.08.",
+            "vom 05.08 zum 16.08.2018",
+            "from 2018/08/05 to 2018/08/16",
+            "from 2018-08-05 to 2018-08-16",
+            "from 08/05 to 08/16",
+            "von 05.08.2018 bis zum 16.08.2018",
+            "from the 2018/08/05 to the 2018/08/16",
+            "starting 2018/08/05 until 2018/08/16",
+        ],
+    ),
+    (
+        "Interval[]{2020-05-11 X:X (X/X) - 2020-05-15 X:X (X/X)}",
+        "2022-07-20T11:43",
+        ["ab dem 11.05.20-15.05.20"],
+    ),
     # ruleDOYDate
     (
         "Interval[]{2017-08-05 X:X (X/X) - 2017-08-16 X:X (X/X)}",
         "2018-03-07T12:43",
         ["5.8. - 16.8.2017", "Samstag 5.8. - Mittwoch 16.8.2017"],
     ),
+    # ruleMonthYear
+    (
+        "Time[]{2018-06-X X:X (X/X)}",
+        "2022-07-07T12:43",
+        ["June 2018", "Jun 2018"],
+    ),
+    # ruleTODTOD
+    (
+        # Not resolving latent time in tests/training
+        "Interval[]{X-X-X 06:00 (X/X) - X-X-X 08:00 (X/X)}",
+        "2022-07-20T10:43",
+        ["between 6- 8 AM", "zwischen 6 und 8h"],
+    ),
     # ruleDateTimeDateTime
     (
         "Interval[]{2018-08-05 08:00 (X/X) - 2018-08-16 13:00 (X/X)}",
@@ -747,4 +782,11 @@ corpus = [
         "2020-02-25T12:34",
         ["3 days 15-18 Nov", "15-18 Nov 3 Nächte", "15-18 Nov für 3 Nächte"],
     ),
+    # ruleYYYYMMDD
+    (
+        "Time[]{2022-11-01 X:X (X/X)}",
+        "2022-10-18T12:34",
+        ["2022/11/01", "2022-11-01", "2022.11.01"],
+    ),
+    ("Time[]{2022-11-30 X:X (X/X)}", "2022-10-18T12:34", ["2022/11/30", "2022/30/11"]),
 ]
